from GenderPrediction.gender_prediction import GenderPredictor

print(GenderPredictor(name='Sounak').predict())